@@ -1,6 +1,7 @@
 #!/usr/bin/env python
 # coding=utf-8
 """
+Console program of graf
 
 (C) 2013 hashnote.net, Alisue
 """
@@ -10,8 +11,11 @@ __date__    = '2013-10-08'
 
 
 def main(args=None):
+    """
+    Execute graf console program
+    """
+    import graf
     from argparse import ArgumentParser
-    from graf.plugins import registry
 
     parser = ArgumentParser()
     parser.add_argument('-i', '--interactive', default=False,
@@ -21,16 +25,9 @@ def main(args=None):
     # parse argument
     args = parser.parse_args(args)
 
-    # create global variables
-    local = globals().copy()
-    #local.update(locals())
-    local.update(registry.raw)
-
     # call all script files
     for script_file in args.script_files:
-        local['__file__'] = script_file
-        local['__name__'] = '__main__'
-        execfile(script_file, local)
+        graf.call(script_file)
 
     # enable interactive shell if no script_files was specified
     if len(args.script_files) == 0:
@@ -43,6 +40,10 @@ def main(args=None):
         except ImportError:
             pass
         import code
+        # create global variables
+        local = globals().copy()
+        # extend graf commands in local
+        graf.use(local)
         code.interact(local=local)
 
 if __name__ == '__main__':
